netapp_ontap.models.fabric_connections_switch API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fabric_connections_switch`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FabricConnectionsSwitchSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FabricConnectionsSwitch object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the fabric_connections_switch.

  `port: FabricConnectionsSwitchPort GET POST PATCH`

    The port of the Fibre Channel switch to which the cluster node port is connected.

  `wwn: str GET`

    The world-wide name (WWN) of the Fibre Channel switch to which the cluster node port is attached.

    Example: 10:00:b1:b2:b3:b4:b4:b6